@@ -37,7 +37,8 @@ class SKLearnTransform(base_component.BaseComponent):
 
         dill_recurse_setting = dill.settings['recurse']
         dill.settings['recurse'] = True
-        preprocessor_pickle = base64.encodebytes(dill.dumps(sklearn_pipeline))
+        # Pickle must be a string to put it in json
+        preprocessor_pickle = base64.encodebytes(dill.dumps(sklearn_pipeline)).decode('utf-8')
         dill.settings['recurse'] = dill_recurse_setting
 
         preprocessor_artifact = channel_utils.as_channel([stfxe_artifacts.SKLearnPrepocessor()])
